summaryrefslogtreecommitdiffstats
path: root/filters/karbon/msod
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /filters/karbon/msod
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'filters/karbon/msod')
-rw-r--r--filters/karbon/msod/msod.cc78
-rw-r--r--filters/karbon/msod/msod.h12
-rw-r--r--filters/karbon/msod/msodimport.cc14
-rw-r--r--filters/karbon/msod/msodimport.h2
4 files changed, 53 insertions, 53 deletions
diff --git a/filters/karbon/msod/msodimport.cc b/filters/karbon/msod/msodimport.cc
index c3ee7b2a..e25889c0 100644
--- a/filters/karbon/msod/msodimport.cc
+++ b/filters/karbon/msod/msodimport.cc
@@ -51,13 +51,13 @@ KoFilter::ConversionStatus MSODImport::convert( const TQCString& from, const TQC
if (to != "application/x-karbon" || from != "image/x-msod")
return KoFilter::NotImplemented;
- // Get configuration data: the tqshape id, and any delay stream that we were given.
- unsigned tqshapeId;
- emit commSignalShapeID( tqshapeId );
+ // Get configuration data: the shape id, and any delay stream that we were given.
+ unsigned shapeId;
+ emit commSignalShapeID( shapeId );
const char *delayStream = 0L;
emit commSignalDelayStream( delayStream );
kdDebug( s_area ) << "##################################################################" << endl;
- kdDebug( s_area ) << "tqshape id: " << tqshapeId << endl;
+ kdDebug( s_area ) << "shape id: " << shapeId << endl;
kdDebug( s_area ) << "delay stream: " << delayStream << endl;
kdDebug( s_area ) << "##################################################################" << endl;
/*
@@ -68,9 +68,9 @@ KoFilter::ConversionStatus MSODImport::convert( const TQCString& from, const TQC
kdDebug(s_area) << "MSODImport::filter: config: " << config << endl;
for (i = 0; i < args.count(); i++)
{
- if (args[i].startsWith("tqshape-id="))
+ if (args[i].startsWith("shape-id="))
{
- tqshapeId = args[i].mid(9).toUInt();
+ shapeId = args[i].mid(9).toUInt();
}
else
if (args[i].startsWith("delay-stream="))
@@ -91,7 +91,7 @@ KoFilter::ConversionStatus MSODImport::convert( const TQCString& from, const TQC
m_text += "<DOC mime=\"application/x-karbon\" syntaxVersion=\"0.1\" editor=\"WMF import filter\">\n";
m_text += " <LAYER name=\"Layer\" visible=\"1\">\n";
- if (!parse(tqshapeId, m_chain->inputFile(), delayStream))
+ if (!parse(shapeId, m_chain->inputFile(), delayStream))
return KoFilter::WrongFormat;
// close doc
diff --git a/filters/karbon/msod/msodimport.h b/filters/karbon/msod/msodimport.h
index 9c721882..9264b7d5 100644
--- a/filters/karbon/msod/msodimport.h
+++ b/filters/karbon/msod/msodimport.h
@@ -68,7 +68,7 @@ protected:
signals:
// Communication signals to the parent filters
void commSignalDelayStream( const char* delay );
- void commSignalShapeID( unsigned int& tqshapeID );
+ void commSignalShapeID( unsigned int& shapeID );
private:
virtual void savePartContents( TQIODevice* file );
diff --git a/filters/karbon/msod/msod.cc b/filters/karbon/msod/msod.cc
index 3e79e3ab..8c4c2795 100644
--- a/filters/karbon/msod/msod.cc
+++ b/filters/karbon/msod/msod.cc
@@ -39,18 +39,18 @@ Msod::Msod(
m_dpi = dpi;
m_images.setAutoDelete(true);
m_opt = new Options(*this);
- m_tqshape.data = 0L;
- m_tqshape.length = 0;
+ m_shape.data = 0L;
+ m_shape.length = 0;
}
Msod::~Msod()
{
- delete [] m_tqshape.data;
+ delete [] m_shape.data;
delete m_opt;
}
void Msod::drawShape(
- unsigned tqshapeType,
+ unsigned shapeType,
TQ_UINT32 bytes,
TQDataStream &operands)
{
@@ -262,25 +262,25 @@ void Msod::drawShape(
};
struct
{
- TQ_UINT32 spid; // The tqshape id
+ TQ_UINT32 spid; // The shape id
union
{
TQ_UINT32 info;
struct
{
- TQ_UINT32 fGroup : 1; // This tqshape is a group tqshape
- TQ_UINT32 fChild : 1; // Not a top-level tqshape
- TQ_UINT32 fPatriarch : 1; // This is the topmost group tqshape.
+ TQ_UINT32 fGroup : 1; // This shape is a group shape
+ TQ_UINT32 fChild : 1; // Not a top-level shape
+ TQ_UINT32 fPatriarch : 1; // This is the topmost group shape.
// Exactly one of these per drawing.
TQ_UINT32 fDeleted : 1; // The shape.has been deleted
- TQ_UINT32 fOleShape : 1; // The tqshape is an OLE object
+ TQ_UINT32 fOleShape : 1; // The shape is an OLE object
TQ_UINT32 fHaveMaster : 1; // Shape has a hspMaster property
TQ_UINT32 fFlipH : 1; // Shape is flipped horizontally
TQ_UINT32 fFlipV : 1; // Shape is flipped vertically
- TQ_UINT32 fConnector : 1; // Connector type of tqshape
+ TQ_UINT32 fConnector : 1; // Connector type of shape
TQ_UINT32 fHaveAnchor : 1; // Shape has an anchor of some kind
- TQ_UINT32 fBackground : 1; // Background tqshape
- TQ_UINT32 fHaveSpt : 1; // Shape has a tqshape type property
+ TQ_UINT32 fBackground : 1; // Background shape
+ TQ_UINT32 fHaveSpt : 1; // Shape has a shape type property
TQ_UINT32 reserved : 20; // Not yet used
} fields;
} grfPersistent;
@@ -291,12 +291,12 @@ void Msod::drawShape(
operands >> data.spid;
operands >> data.grfPersistent.info;
bytes -= 8;
- kdDebug(s_area) << "tqshape-id: " << data.spid << " type: " << funcTab[tqshapeType] << " (" << tqshapeType << ")" <<
+ kdDebug(s_area) << "shape-id: " << data.spid << " type: " << funcTab[shapeType] << " (" << shapeType << ")" <<
(data.grfPersistent.fields.fGroup ? " group" : "") <<
(data.grfPersistent.fields.fChild ? " child" : "") <<
(data.grfPersistent.fields.fPatriarch ? " patriarch" : "") <<
(data.grfPersistent.fields.fDeleted ? " deleted" : "") <<
- (data.grfPersistent.fields.fOleShape ? " oletqshape" : "") <<
+ (data.grfPersistent.fields.fOleShape ? " oleshape" : "") <<
(data.grfPersistent.fields.fHaveMaster ? " master" : "") <<
(data.grfPersistent.fields.fFlipH ? " flipv" : "") <<
(data.grfPersistent.fields.fConnector ? " connector" : "") <<
@@ -309,9 +309,9 @@ void Msod::drawShape(
if ((!m_isRequiredDrawing) && (m_requestedShapeId != data.spid))
return;
- // An active tqshape! Let's draw it...
+ // An active shape! Let's draw it...
- switch (tqshapeType)
+ switch (shapeType)
{
case 0:
if (m_opt->m_pVertices)
@@ -493,7 +493,7 @@ TQSize Msod::normaliseSize(
}
bool Msod::parse(
- unsigned tqshapeId,
+ unsigned shapeId,
const TQString &file,
const char *delayStream)
{
@@ -505,19 +505,19 @@ bool Msod::parse(
return false;
}
TQDataStream stream(&in);
- bool result = parse(tqshapeId, stream, in.size(), delayStream);
+ bool result = parse(shapeId, stream, in.size(), delayStream);
in.close();
return result;
}
bool Msod::parse(
- unsigned tqshapeId,
+ unsigned shapeId,
TQDataStream &stream,
unsigned size,
const char *delayStream)
{
stream.setByteOrder(TQDataStream::LittleEndian); // Great, I love TQt !
- m_requestedShapeId = tqshapeId;
+ m_requestedShapeId = shapeId;
m_isRequiredDrawing = false;
m_delayStream = delayStream;
@@ -854,8 +854,8 @@ void Msod::opDg(Header &, TQ_UINT32, TQDataStream &operands)
{
struct
{
- TQ_UINT32 csp; // The number of tqshapes in this drawing.
- TQ_UINT32 spidCur; // The last tqshape ID given to an SP in this DG.
+ TQ_UINT32 csp; // The number of shapes in this drawing.
+ TQ_UINT32 spidCur; // The last shape ID given to an SP in this DG.
} data;
operands >> data.csp >> data.spidCur;
@@ -878,10 +878,10 @@ void Msod::opDgg(Header &, TQ_UINT32, TQDataStream &operands)
{
struct
{
- TQ_UINT32 spidMax; // The current maximum tqshape ID.
+ TQ_UINT32 spidMax; // The current maximum shape ID.
TQ_UINT32 cidcl; // The number of ID clusters (FIDCLs).
- TQ_UINT32 cspSaved; // The total number of tqshapes saved.
- // (including deleted tqshapes, if undo
+ TQ_UINT32 cspSaved; // The total number of shapes saved.
+ // (including deleted shapes, if undo
// information was saved).
TQ_UINT32 cdgSaved; // The total number of drawings saved.
} data;
@@ -896,7 +896,7 @@ void Msod::opDgg(Header &, TQ_UINT32, TQDataStream &operands)
unsigned i;
operands >> data.spidMax >> data.cidcl >> data.cspSaved >> data.cdgSaved;
- kdDebug(s_area) << data.cspSaved << " tqshapes in " <<
+ kdDebug(s_area) << data.cspSaved << " shapes in " <<
data.cidcl - 1 << " clusters in " <<
data.cdgSaved << " drawings" << endl;
for (i = 0; i < data.cidcl - 1; i++)
@@ -943,31 +943,31 @@ void Msod::opSolvercontainer(Header &, TQ_UINT32 bytes, TQDataStream &operands)
void Msod::opSp(Header &op, TQ_UINT32 bytes, TQDataStream &operands)
{
- // We want to defer the act of drawing a tqshape until we have seen any options
+ // We want to defer the act of drawing a shape until we have seen any options
// that may affect it. Thus, we merely store the data away, and let opSpContainer
// do all the ahrd work.
- m_tqshape.type = op.opcode.fields.inst;
- m_tqshape.length = bytes;
- m_tqshape.data = new char [bytes];
- operands.readRawBytes(m_tqshape.data, bytes);
+ m_shape.type = op.opcode.fields.inst;
+ m_shape.length = bytes;
+ m_shape.data = new char [bytes];
+ operands.readRawBytes(m_shape.data, bytes);
}
void Msod::opSpcontainer(Header &, TQ_UINT32 bytes, TQDataStream &operands)
{
walk(bytes, operands);
- // Having gathered all the information for this tqshape, we can now draw it.
+ // Having gathered all the information for this shape, we can now draw it.
TQByteArray a;
- a.setRawData(m_tqshape.data, m_tqshape.length);
+ a.setRawData(m_shape.data, m_shape.length);
TQDataStream s(a, IO_ReadOnly);
s.setByteOrder(TQDataStream::LittleEndian); // Great, I love TQt !
- drawShape(m_tqshape.type, m_tqshape.length, s);
- a.resetRawData(m_tqshape.data, m_tqshape.length);
- delete [] m_tqshape.data;
- m_tqshape.data = 0L;
+ drawShape(m_shape.type, m_shape.length, s);
+ a.resetRawData(m_shape.data, m_shape.length);
+ delete [] m_shape.data;
+ m_shape.data = 0L;
}
void Msod::opSpgr(Header &, TQ_UINT32, TQDataStream &operands)
@@ -1097,7 +1097,7 @@ void Msod::Options::initialise()
m_geoTop = 0;
m_geoRight = 21600;
m_geoBottom = 21600;
- m_tqshapePath = 1;
+ m_shapePath = 1;
delete m_pVertices;
m_pVertices = 0L;
m_fShadowOK = true;
@@ -1233,7 +1233,7 @@ void Msod::Options::walk(TQ_UINT32 bytes, TQDataStream &operands)
m_geoBottom = op.value;
break;
case 324:
- m_tqshapePath = op.value;
+ m_shapePath = op.value;
break;
case 383:
m_fShadowOK = (op.value & 0x0020) != 0;
diff --git a/filters/karbon/msod/msod.h b/filters/karbon/msod/msod.h
index f53146bf..3db6fc2f 100644
--- a/filters/karbon/msod/msod.h
+++ b/filters/karbon/msod/msod.h
@@ -44,15 +44,15 @@ public:
unsigned dpi);
virtual ~Msod();
// Called to parse the given file. We extract a drawing by tqshapeId.
// If the drawing is not found, the return value will be false.
bool parse(
- unsigned tqshapeId,
+ unsigned shapeId,
const TQString &file,
const char *delayStream = 0L);
bool parse(
- unsigned tqshapeId,
+ unsigned shapeId,
TQDataStream &stream,
unsigned size,
const char *delayStream = 0L);
@@ -114,14 +114,14 @@ private:
unsigned type;
char *data;
unsigned length;
- } m_tqshape;
+ } m_shape;
TQPoint normalisePoint(
TQDataStream &operands);
TQSize normaliseSize(
TQDataStream &operands);
void drawShape(
- unsigned tqshapeType,
+ unsigned shapeType,
TQ_UINT32 bytes,
TQDataStream &operands);
@@ -244,7 +244,7 @@ private:
TQ_UINT32 m_geoTop;
TQ_UINT32 m_geoRight;
TQ_UINT32 m_geoBottom;
- TQ_UINT32 m_tqshapePath;
+ TQ_UINT32 m_shapePath;
TQPointArray *m_pVertices;
bool m_fShadowOK;
bool m_f3DOK;
@@ -44,15 +44,15 @@ public:
unsigned dpi);
virtual ~Msod();
- // Called to parse the given file. We extract a drawing by tqshapeId.
+ // Called to parse the given file. We extract a drawing by shapeId.
// If the drawing is not found, the return value will be false.
bool parse(